]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - server.h
update README
[paraslash.git] / server.h
index da777f771d90386e2626183b6ba120e4bde49514..fcda7a3ace835d65c0e960640291396e62f628ea 100644 (file)
--- a/server.h
+++ b/server.h
@@ -141,10 +141,10 @@ struct misc_meta_data{
        pid_t server_pid;
 /** a string that gets filled in by the current audio file selector */
        char selector_info[MMD_INFO_SIZE];
-/** the number if the current database tool */
-       int dbt_num;
-/** commands set this to non-zero to request a database tool change */
-       int dbt_change;
+/** the number if the current audio file selector */
+       int selector_num;
+/** commands set this to non-zero to change the current selector */
+       int selector_change;
 /** used by the sender command */
        struct sender_command_data sender_cmd_data;
 };